@@ -4,6 +4,7 @@ use Mojo::Base 'Mojo::EventEmitter';
 use Carp 'croak';
 use DBI;
 use DBD::SQLite;
+use DBD::SQLite::Constants ':database_connection_configuration_options';
 use File::Spec::Functions 'catfile';
 use File::Temp;
 use Mojo::SQLite::Database;
@@ -13,7 +14,7 @@ use SQL::Abstract;
 use URI;
 use URI::db;
 
-our $VERSION = '3.001';
+our $VERSION = '3.003';
 
 has abstract => sub { SQL::Abstract->new(name_sep => '.', quote_char => '"') };
 has 'auto_migrate';
@@ -82,6 +83,8 @@ sub _dequeue {
   
   my $dbh = DBI->connect($self->dsn, undef, undef, $self->options)
     // croak "DBI connection to @{[$self->dsn]} failed: $DBI::errstr"; # RaiseError disabled
+  $dbh->sqlite_db_config(SQLITE_DBCONFIG_DQS_DDL, 0);
+  $dbh->sqlite_db_config(SQLITE_DBCONFIG_DQS_DML, 0);
   unless ($self->options->{no_wal}) {
     $dbh->do('pragma journal_mode=WAL');
     $dbh->do('pragma synchronous=NORMAL');
